@@ -20,7 +20,7 @@ summarise_variable <- function(dataset, column) {
     allna_summary(dataset, column)
   } else if ("factor" %in% x) {
     factor_summary(dataset, column)
-  } else if ( x[1] == "haven_labelled") {
+  } else if ("haven_labelled" %in% x) {
     label_summary(dataset, column)
   } else if ("POSIXt" %in% x | "Date" %in% x) {
     datetime_summary(dataset, column)
